==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/RouteTableRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.RouteTableRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property carrierGatewayId Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
 * @property cidrBlock The CIDR block of the route.
 * @property coreNetworkArn The Amazon Resource Name (ARN) of a core network.
 * @property destinationPrefixListId The ID of a managed prefix list destination of the route.
 * One of the following target arguments must be supplied:
 * @property egressOnlyGatewayId Identifier of a VPC Egress Only Internet Gateway.
 * @property gatewayId Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
 * @property ipv6CidrBlock The Ipv6 CIDR block of the route.
 * @property localGatewayId Identifier of a Outpost local gateway.
 * @property natGatewayId Identifier of a VPC NAT gateway.
 * @property networkInterfaceId Identifier of an EC2 network interface.
 * @property transitGatewayId Identifier of an EC2 Transit Gateway.
 * @property vpcEndpointId Identifier of a VPC Endpoint.
 * @property vpcPeeringConnectionId Identifier of a VPC peering connection.
 * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
 */
public data class RouteTableRouteArgs(
    public val carrierGatewayId: Output<String>? = null,
    public val cidrBlock: Output<String>? = null,
    public val coreNetworkArn: Output<String>? = null,
    public val destinationPrefixListId: Output<String>? = null,
    public val egressOnlyGatewayId: Output<String>? = null,
    public val gatewayId: Output<String>? = null,
    public val ipv6CidrBlock: Output<String>? = null,
    public val localGatewayId: Output<String>? = null,
    public val natGatewayId: Output<String>? = null,
    public val networkInterfaceId: Output<String>? = null,
    public val transitGatewayId: Output<String>? = null,
    public val vpcEndpointId: Output<String>? = null,
    public val vpcPeeringConnectionId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.RouteTableRouteArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.RouteTableRouteArgs =
        com.pulumi.aws.ec2.inputs.RouteTableRouteArgs.builder()
            .carrierGatewayId(carrierGatewayId?.applyValue({ args0 -> args0 }))
            .cidrBlock(cidrBlock?.applyValue({ args0 -> args0 }))
            .coreNetworkArn(coreNetworkArn?.applyValue({ args0 -> args0 }))
            .destinationPrefixListId(destinationPrefixListId?.applyValue({ args0 -> args0 }))
            .egressOnlyGatewayId(egressOnlyGatewayId?.applyValue({ args0 -> args0 }))
            .gatewayId(gatewayId?.applyValue({ args0 -> args0 }))
            .ipv6CidrBlock(ipv6CidrBlock?.applyValue({ args0 -> args0 }))
            .localGatewayId(localGatewayId?.applyValue({ args0 -> args0 }))
            .natGatewayId(natGatewayId?.applyValue({ args0 -> args0 }))
            .networkInterfaceId(networkInterfaceId?.applyValue({ args0 -> args0 }))
            .transitGatewayId(transitGatewayId?.applyValue({ args0 -> args0 }))
            .vpcEndpointId(vpcEndpointId?.applyValue({ args0 -> args0 }))
            .vpcPeeringConnectionId(vpcPeeringConnectionId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteTableRouteArgs].
 */
@PulumiTagMarker
public class RouteTableRouteArgsBuilder internal constructor() {
    private var carrierGatewayId: Output<String>? = null

    private var cidrBlock: Output<String>? = null

    private var coreNetworkArn: Output<String>? = null

    private var destinationPrefixListId: Output<String>? = null

    private var egressOnlyGatewayId: Output<String>? = null

    private var gatewayId: Output<String>? = null

    private var ipv6CidrBlock: Output<String>? = null

    private var localGatewayId: Output<String>? = null

    private var natGatewayId: Output<String>? = null

    private var networkInterfaceId: Output<String>? = null

    private var transitGatewayId: Output<String>? = null

    private var vpcEndpointId: Output<String>? = null

    private var vpcPeeringConnectionId: Output<String>? = null

    /**
     * @param value Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    @JvmName("ocivdjkekbadvfoq")
    public suspend fun carrierGatewayId(`value`: Output<String>) {
        this.carrierGatewayId = value
    }

    /**
     * @param value The CIDR block of the route.
     */
    @JvmName("wqdhpakryxuftcrh")
    public suspend fun cidrBlock(`value`: Output<String>) {
        this.cidrBlock = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of a core network.
     */
    @JvmName("tkmcnaqplmutbuxb")
    public suspend fun coreNetworkArn(`value`: Output<String>) {
        this.coreNetworkArn = value
    }

    /**
     * @param value The ID of a managed prefix list destination of the route.
     * One of the following target arguments must be supplied:
     */
    @JvmName("wsjbuccltpgjyoin")
    public suspend fun destinationPrefixListId(`value`: Output<String>) {
        this.destinationPrefixListId = value
    }

    /**
     * @param value Identifier of a VPC Egress Only Internet Gateway.
     */
    @JvmName("rusgqaoutyfyxlyd")
    public suspend fun egressOnlyGatewayId(`value`: Output<String>) {
        this.egressOnlyGatewayId = value
    }

    /**
     * @param value Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
     */
    @JvmName("rjuxqunvxkgffctk")
    public suspend fun gatewayId(`value`: Output<String>) {
        this.gatewayId = value
    }

    /**
     * @param value The Ipv6 CIDR block of the route.
     */
    @JvmName("tyujdukbuoyjhwyt")
    public suspend fun ipv6CidrBlock(`value`: Output<String>) {
        this.ipv6CidrBlock = value
    }

    /**
     * @param value Identifier of a Outpost local gateway.
     */
    @JvmName("yngksajebexelwga")
    public suspend fun localGatewayId(`value`: Output<String>) {
        this.localGatewayId = value
    }

    /**
     * @param value Identifier of a VPC NAT gateway.
     */
    @JvmName("wlodtmxemjokuyvf")
    public suspend fun natGatewayId(`value`: Output<String>) {
        this.natGatewayId = value
    }

    /**
     * @param value Identifier of an EC2 network interface.
     */
    @JvmName("dpgulnmqpnhswhsc")
    public suspend fun networkInterfaceId(`value`: Output<String>) {
        this.networkInterfaceId = value
    }

    /**
     * @param value Identifier of an EC2 Transit Gateway.
     */
    @JvmName("dcwqeqydwpnldcdt")
    public suspend fun transitGatewayId(`value`: Output<String>) {
        this.transitGatewayId = value
    }

    /**
     * @param value Identifier of a VPC Endpoint.
     */
    @JvmName("ghpwdpnbfddparqd")
    public suspend fun vpcEndpointId(`value`: Output<String>) {
        this.vpcEndpointId = value
    }

    /**
     * @param value Identifier of a VPC peering connection.
     * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
     */
    @JvmName("bdrlhljuduqytdsx")
    public suspend fun vpcPeeringConnectionId(`value`: Output<String>) {
        this.vpcPeeringConnectionId = value
    }

    /**
     * @param value Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    @JvmName("ttlcoiwyvbtaetyi")
    public suspend fun carrierGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.carrierGatewayId = mapped
    }

    /**
     * @param value The CIDR block of the route.
     */
    @JvmName("cprwmhmajedwpjnc")
    public suspend fun cidrBlock(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cidrBlock = mapped
    }

    /**
     * @param value The Amazon Resource Name (ARN) of a core network.
     */
    @JvmName("cqgjhhuuhixiqvbd")
    public suspend fun coreNetworkArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coreNetworkArn = mapped
    }

    /**
     * @param value The ID of a managed prefix list destination of the route.
     * One of the following target arguments must be supplied:
     */
    @JvmName("htojewulfvxtboso")
    public suspend fun destinationPrefixListId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPrefixListId = mapped
    }

    /**
     * @param value Identifier of a VPC Egress Only Internet Gateway.
     */
    @JvmName("mtfodgjtclkiuktl")
    public suspend fun egressOnlyGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.egressOnlyGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
     */
    @JvmName("ederikskcutbwqon")
    public suspend fun gatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayId = mapped
    }

    /**
     * @param value The Ipv6 CIDR block of the route.
     */
    @JvmName("ognohmknxdsgrqyy")
    public suspend fun ipv6CidrBlock(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6CidrBlock = mapped
    }

    /**
     * @param value Identifier of a Outpost local gateway.
     */
    @JvmName("csmpyyljdveyqlau")
    public suspend fun localGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.localGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC NAT gateway.
     */
    @JvmName("txehpguirgtvxcru")
    public suspend fun natGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.natGatewayId = mapped
    }

    /**
     * @param value Identifier of an EC2 network interface.
     */
    @JvmName("irvolupmmmgqclqd")
    public suspend fun networkInterfaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaceId = mapped
    }

    /**
     * @param value Identifier of an EC2 Transit Gateway.
     */
    @JvmName("puvnsmfrenteijso")
    public suspend fun transitGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transitGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC Endpoint.
     */
    @JvmName("eowjjhodoelctuld")
    public suspend fun vpcEndpointId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcEndpointId = mapped
    }

    /**
     * @param value Identifier of a VPC peering connection.
     * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
     */
    @JvmName("fbghmbaqbahuxiaq")
    public suspend fun vpcPeeringConnectionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcPeeringConnectionId = mapped
    }

    internal fun build(): RouteTableRouteArgs = RouteTableRouteArgs(
        carrierGatewayId = carrierGatewayId,
        cidrBlock = cidrBlock,
        coreNetworkArn = coreNetworkArn,
        destinationPrefixListId = destinationPrefixListId,
        egressOnlyGatewayId = egressOnlyGatewayId,
        gatewayId = gatewayId,
        ipv6CidrBlock = ipv6CidrBlock,
        localGatewayId = localGatewayId,
        natGatewayId = natGatewayId,
        networkInterfaceId = networkInterfaceId,
        transitGatewayId = transitGatewayId,
        vpcEndpointId = vpcEndpointId,
        vpcPeeringConnectionId = vpcPeeringConnectionId,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/RouteTableRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.RouteTableRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property carrierGatewayId Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
 * @property cidrBlock The CIDR block of the route.
 * @property coreNetworkArn The Amazon Resource Name (ARN) of a core network.
 * @property destinationPrefixListId The ID of a managed prefix list destination of the route.
 * One of the following target arguments must be supplied:
 * @property egressOnlyGatewayId Identifier of a VPC Egress Only Internet Gateway.
 * @property gatewayId Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
 * @property ipv6CidrBlock The Ipv6 CIDR block of the route.
 * @property localGatewayId Identifier of a Outpost local gateway.
 * @property natGatewayId Identifier of a VPC NAT gateway.
 * @property networkInterfaceId Identifier of an EC2 network interface.
 * @property transitGatewayId Identifier of an EC2 Transit Gateway.
 * @property vpcEndpointId Identifier of a VPC Endpoint.
 * @property vpcPeeringConnectionId Identifier of a VPC peering connection.
 * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
 */
public data class RouteTableRouteArgs(
    public val carrierGatewayId: Output<String>? = null,
    public val cidrBlock: Output<String>? = null,
    public val coreNetworkArn: Output<String>? = null,
    public val destinationPrefixListId: Output<String>? = null,
    public val egressOnlyGatewayId: Output<String>? = null,
    public val gatewayId: Output<String>? = null,
    public val ipv6CidrBlock: Output<String>? = null,
    public val localGatewayId: Output<String>? = null,
    public val natGatewayId: Output<String>? = null,
    public val networkInterfaceId: Output<String>? = null,
    public val transitGatewayId: Output<String>? = null,
    public val vpcEndpointId: Output<String>? = null,
    public val vpcPeeringConnectionId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.RouteTableRouteArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.RouteTableRouteArgs =
        com.pulumi.aws.ec2.inputs.RouteTableRouteArgs.builder()
            .carrierGatewayId(carrierGatewayId?.applyValue({ args0 -> args0 }))
            .cidrBlock(cidrBlock?.applyValue({ args0 -> args0 }))
            .coreNetworkArn(coreNetworkArn?.applyValue({ args0 -> args0 }))
            .destinationPrefixListId(destinationPrefixListId?.applyValue({ args0 -> args0 }))
            .egressOnlyGatewayId(egressOnlyGatewayId?.applyValue({ args0 -> args0 }))
            .gatewayId(gatewayId?.applyValue({ args0 -> args0 }))
            .ipv6CidrBlock(ipv6CidrBlock?.applyValue({ args0 -> args0 }))
            .localGatewayId(localGatewayId?.applyValue({ args0 -> args0 }))
            .natGatewayId(natGatewayId?.applyValue({ args0 -> args0 }))
            .networkInterfaceId(networkInterfaceId?.applyValue({ args0 -> args0 }))
            .transitGatewayId(transitGatewayId?.applyValue({ args0 -> args0 }))
            .vpcEndpointId(vpcEndpointId?.applyValue({ args0 -> args0 }))
            .vpcPeeringConnectionId(vpcPeeringConnectionId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteTableRouteArgs].
 */
@PulumiTagMarker
public class RouteTableRouteArgsBuilder internal constructor() {
    private var carrierGatewayId: Output<String>? = null

    private var cidrBlock: Output<String>? = null

    private var coreNetworkArn: Output<String>? = null

    private var destinationPrefixListId: Output<String>? = null

    private var egressOnlyGatewayId: Output<String>? = null

    private var gatewayId: Output<String>? = null

    private var ipv6CidrBlock: Output<String>? = null

    private var localGatewayId: Output<String>? = null

    private var natGatewayId: Output<String>? = null

    private var networkInterfaceId: Output<String>? = null

    private var transitGatewayId: Output<String>? = null

    private var vpcEndpointId: Output<String>? = null

    private var vpcPeeringConnectionId: Output<String>? = null

    /**
     * @param value Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    @JvmName("flxktfrpeldvhvrh")
    public suspend fun carrierGatewayId(`value`: Output<String>) {
        this.carrierGatewayId = value
    }

    /**
     * @param value The CIDR block of the route.
     */
    @JvmName("ftgkqdmrhflpenub")
    public suspend fun cidrBlock(`value`: Output<String>) {
        this.cidrBlock = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of a core network.
     */
    @JvmName("vteiaduxipnofpwd")
    public suspend fun coreNetworkArn(`value`: Output<String>) {
        this.coreNetworkArn = value
    }

    /**
     * @param value The ID of a managed prefix list destination of the route.
     * One of the following target arguments must be supplied:
     */
    @JvmName("ofysbamdodxsrdok")
    public suspend fun destinationPrefixListId(`value`: Output<String>) {
        this.destinationPrefixListId = value
    }

    /**
     * @param value Identifier of a VPC Egress Only Internet Gateway.
     */
    @JvmName("jhrrkjhyteyfiejh")
    public suspend fun egressOnlyGatewayId(`value`: Output<String>) {
        this.egressOnlyGatewayId = value
    }

    /**
     * @param value Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
     */
    @JvmName("ecyfikpbdvofohqy")
    public suspend fun gatewayId(`value`: Output<String>) {
        this.gatewayId = value
    }

    /**
     * @param value The Ipv6 CIDR block of the route.
     */
    @JvmName("rvyodugcxpepadtd")
    public suspend fun ipv6CidrBlock(`value`: Output<String>) {
        this.ipv6CidrBlock = value
    }

    /**
     * @param value Identifier of a Outpost local gateway.
     */
    @JvmName("lgeeuobnmvsfnrje")
    public suspend fun localGatewayId(`value`: Output<String>) {
        this.localGatewayId = value
    }

    /**
     * @param value Identifier of a VPC NAT gateway.
     */
    @JvmName("qjqdxpmmpksmcsof")
    public suspend fun natGatewayId(`value`: Output<String>) {
        this.natGatewayId = value
    }

    /**
     * @param value Identifier of an EC2 network interface.
     */
    @JvmName("bqhrppbplwoxkrhd")
    public suspend fun networkInterfaceId(`value`: Output<String>) {
        this.networkInterfaceId = value
    }

    /**
     * @param value Identifier of an EC2 Transit Gateway.
     */
    @JvmName("skhflaksmresimuv")
    public suspend fun transitGatewayId(`value`: Output<String>) {
        this.transitGatewayId = value
    }

    /**
     * @param value Identifier of a VPC Endpoint.
     */
    @JvmName("vghlcyfovjpyitqw")
    public suspend fun vpcEndpointId(`value`: Output<String>) {
        this.vpcEndpointId = value
    }

    /**
     * @param value Identifier of a VPC peering connection.
     * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
     */
    @JvmName("kmrteakvrqopcono")
    public suspend fun vpcPeeringConnectionId(`value`: Output<String>) {
        this.vpcPeeringConnectionId = value
    }

    /**
     * @param value Identifier of a carrier gateway. This attribute can only be used when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    @JvmName("xcwlqxewlsqppasy")
    public suspend fun carrierGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.carrierGatewayId = mapped
    }

    /**
     * @param value The CIDR block of the route.
     */
    @JvmName("nmxyojshmtirpphj")
    public suspend fun cidrBlock(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cidrBlock = mapped
    }

    /**
     * @param value The Amazon Resource Name (ARN) of a core network.
     */
    @JvmName("jxyxpofoenjamtut")
    public suspend fun coreNetworkArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coreNetworkArn = mapped
    }

    /**
     * @param value The ID of a managed prefix list destination of the route.
     * One of the following target arguments must be supplied:
     */
    @JvmName("rivfcxhriexvljbt")
    public suspend fun destinationPrefixListId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPrefixListId = mapped
    }

    /**
     * @param value Identifier of a VPC Egress Only Internet Gateway.
     */
    @JvmName("utwmcssflpprosie")
    public suspend fun egressOnlyGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.egressOnlyGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC internet gateway, virtual private gateway, or `local`. `local` routes cannot be created but can be adopted or imported. See the example above.
     */
    @JvmName("mxpkuitfknqcwwmh")
    public suspend fun gatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayId = mapped
    }

    /**
     * @param value The Ipv6 CIDR block of the route.
     */
    @JvmName("triueskrsslwpigc")
    public suspend fun ipv6CidrBlock(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6CidrBlock = mapped
    }

    /**
     * @param value Identifier of a Outpost local gateway.
     */
    @JvmName("hgkftxkoswhkmmbv")
    public suspend fun localGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.localGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC NAT gateway.
     */
    @JvmName("vtnqwcyngauxmede")
    public suspend fun natGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.natGatewayId = mapped
    }

    /**
     * @param value Identifier of an EC2 network interface.
     */
    @JvmName("vopdtxvaapmjjnao")
    public suspend fun networkInterfaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkInterfaceId = mapped
    }

    /**
     * @param value Identifier of an EC2 Transit Gateway.
     */
    @JvmName("nqtpnbdipdyxdmbv")
    public suspend fun transitGatewayId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transitGatewayId = mapped
    }

    /**
     * @param value Identifier of a VPC Endpoint.
     */
    @JvmName("biytjwvegpauqlcv")
    public suspend fun vpcEndpointId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcEndpointId = mapped
    }

    /**
     * @param value Identifier of a VPC peering connection.
     * Note that the default route, mapping the VPC's CIDR block to "local", is created implicitly and cannot be specified.
     */
    @JvmName("bloudscuyuanodny")
    public suspend fun vpcPeeringConnectionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcPeeringConnectionId = mapped
    }

    internal fun build(): RouteTableRouteArgs = RouteTableRouteArgs(
        carrierGatewayId = carrierGatewayId,
        cidrBlock = cidrBlock,
        coreNetworkArn = coreNetworkArn,
        destinationPrefixListId = destinationPrefixListId,
        egressOnlyGatewayId = egressOnlyGatewayId,
        gatewayId = gatewayId,
        ipv6CidrBlock = ipv6CidrBlock,
        localGatewayId = localGatewayId,
        natGatewayId = natGatewayId,
        networkInterfaceId = networkInterfaceId,
        transitGatewayId = transitGatewayId,
        vpcEndpointId = vpcEndpointId,
        vpcPeeringConnectionId = vpcPeeringConnectionId,
    )
}
